@@ -2281,10 +2281,18 @@ EAction.warnNotLineArcCircleEllipseSplinePolyline = function() {
     EAction.handleUserWarning(qsTr("Entity is not a line, arc, circle, ellipse, spline or polyline."));
 };
 
+EAction.warnNotCircleEllipseSplinePolyline = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a circle, ellipse, spline or polyline."));
+};
+
 EAction.warnNotPolyline = function() {
     EAction.handleUserWarning(qsTr("Entity is not a polyline."));
 };
 
+EAction.warnNotClosedPolyline = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a closed polyline."));
+};
+
 EAction.warnNotSplineWithFitPoints = function() {
     EAction.handleUserWarning(qsTr("Entity is not a spline with fit points."));
 };
